#ifndef MINGWTLIB_H_
#define MINGWTLIB_H_
#include <sys/stat.h>
#include <signal.h>
#include <errno.h>

typedef int gid_t;
typedef int uid_t;
typedef int uintmax_t;
struct group {
  gid_t	gr_gid;
  char **      	gr_mem;
  char *	gr_name;
};

#define SIGQUIT -3	/* signal stubs */
#define SIGPIPE -13
#define SIGKILL -9
#define SIGUSR1 -30

#define PROGRAM_NAME(x) base_name(x)

/* helpers - used for new functionality */
/* overrides - replace from tool libraries */
char* base_name(char const *);
void strip_trailing_slashes (char*);
void mingw_fix_slashes(char*);
int win32_get_fattr(const char*);
void win32_mode_string(int, char*);

/* stubs */
int euidaccess (const char*, int);
char* getgroup(int);
char* getuser(int);
uid_t getuid();
uid_t geteuid();
void setuid(uid_t id);
struct group *getgrid(gid_t);
struct group *getgrnam(const char*);
char* getlogin(void);

int chown(const char*, uid_t, gid_t);
int kill(pid_t, int);
int lchown(const char*, short, short);
int link(const char*, const char*);
int lstat(const char*, struct stat*);
int mkdir2(char*, int);
int mknod(const char* node, mode_t, dev_t);
void nice(int nv);
int readlink(const char*, char*, size_t);

/* WINDOWS does not support the following stuff.  
   Here are trivial substitute that will do. */

#define S_IFLABEL	0x5000
#define S_ISLABEL(m)	(((m) & 0xf000) == S_IFLABEL)

#define LCHOWN(FILE, OWNER, GROUP) 1
#define FIXPATH(BUF,PATH) _fullpath(BUF, PATH, PATH_MAX)
#define PUTCHAR(CH) putchar(CH)

#endif


